#!/bin/bash
PGDATA="/var/lib/pgsql"
rhel=$(rpm --query --queryformat '%{RELEASE}' rpm | grep --only-matching [[:digit:]]*\$)

#Try to start/reload the postgresql instance once
restart_postgresql(){
	if [ $rhel -ge 7 ]
	then
		systemctl restart postgresql
	else
		service postgresql stop || :
		service postgresql start
	fi
}

case "$1" in
	'install')
	id op5lsu 2&>1 >/dev/null
	ret=$?

	if [ $ret -gt 0 ]; then
		useradd -m op5lsu
	fi

	if [ ! -f "/var/lib/pgsql/data/PG_VERSION" ]
	then
		if [ $rhel -ge 7 ]
		then
			postgresql-setup initdb
		else
			service postgresql initdb
		fi
	fi

	[ -f $PGDATA/.i18n ] && mv -f $PGDATA/.i18n $PGDATA/.i18n.old;
	install -p -g postgres -o postgres -m 600 $2/.i18n $PGDATA

	[ -f $PGDATA/pg_hba.conf ] && mv -f $PGDATA/pg_hba.conf $PGDATA/pg_hba.conf.old;
	install -p -g postgres -o postgres -m 600 $2/pg_hba.conf $PGDATA

	if [ $rhel -ge 7 ]
	then
		systemctl enable postgresql
	else
		chkconfig postgresql on
	fi
	restart_postgresql
	;;
	'upgrade')
	[ -f $PGDATA/.i18n ] && mv -f $PGDATA/.i18n $PGDATA/.i18n.new;
	install -p -g postgres -o postgres -m 600 $2/.i18n $PGDATA

	[ -f $PGDATA/pg_hba.conf ] && mv -f $PGDATA/pg_hba.conf $PGDATA/pg_hba.conf.new;
	install -p -g postgres -o postgres -m 600 $2/pg_hba.conf $PGDATA
	restart_postgresql
	;;
	'renew')
	[ -f $PGDATA/.i18n.new ] && rm -f $PGDATA/.i18n.new;
	[ -f $PGDATA/pg_hba.conf.new ] && rm -f $PGDATA/pg_hba.conf.new;
	restart_postgresql
	;;
	'uninstall')
	[ -f $PGDATA/.i18n.old ] && mv -f $PGDATA/.i18n.old $PGDATA/.i18n;
	[ -f $PGDATA/pg_hba.conf.old ] && mv -f $PGDATA/pg_hba.conf.old $PGDATA/pg_hba.conf;
	if [ $rhel -ge 7 ]
	then
		systemctl disable postgresql
	else
		chkconfig postgresql off
	fi

	userdel -r op5lsu
	;;
	*)
	echo "Bad parameter";
	;;
esac
